@@ -134,7 +134,9 @@
       END IF
       LOPEN = .TRUE.
 
+      IF (IWS.NE.3) THEN
       CALL SGCLST(CLRMAP)
+      END IF
 
       RETURN
 *-----------------------------------------------------------------------
@@ -258,12 +260,13 @@
 
       RETURN
 *-----------------------------------------------------------------------
-      ENTRY SWSCLI(ICLIDX)
+      ENTRY SWSCLI(ICLIDX,LFCATR)
 
 *     / SET LINE COLOR INDEX /
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWSCLI', CNOPN)
+
       IF (IWS.EQ.1) CALL ZXSCLI(ICLIDX)
       IF (IWS.EQ.2) CALL Z1SCLI(ICLIDX)
       IF (IWS.EQ.3) CALL ZTSCLI(ICLIDX)
@@ -274,10 +277,13 @@
       ENTRY SWSLCL(ICOLOR)
 
 *     / SET LINE COLOR IN 24BIT RGB /
+      CALL SGQCL(ICLIDX,NR,NB,NG)
+      CALL UIFPAC(NR,NG,NB,NCOLOR)
 
-      IF (IWS.EQ.1) CALL ZXSLCL(ICOLOR)
-      IF (IWS.EQ.2) CALL Z1SLCL(ICOLOR)
-      IF (IWS.EQ.4) CALL ZGSLCL(ICOLOR)
+      IF (IWS.EQ.1) CALL ZXSLCL(NCOLOR)
+      IF (IWS.EQ.2) CALL Z1SLCL(NCOLOR)
+*      IF (IWS.EQ.3) CALL ZTSLCL(NCOLOR)
+      IF (IWS.EQ.4) CALL ZGSLCL(NCOLOR)
 
       RETURN
 *-----------------------------------------------------------------------
